@@ -357,6 +357,14 @@ sub convert_tags_to_doxygen($)
     # Remove all para tags (from tmpl sgml files).
     s"&lt;/?para&gt;""g;
 
+    # Use our doxgen since/newin tags:
+    # TODO: Do this generically, regardless of the number:
+    s"Since: 2\.2"\@newin2p2"mg;
+    s"Since: 2\.4"\@newin2p4"mg;
+    s"Since: 2\.6"\@newin2p6"mg;
+    s"Since: 2\.8"\@newin2p8"mg;
+    s"Since: 2\.10"\@newin2p10"mg;
+
     s"\b-&gt;\b"->"g;
 
     # Doxygen is too dumb to handle &mdash;
